# ExternalAPIHoldingBasePreviousOwnerRequest


## Properties

Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**name** | **str** |  | 
**code** | **str** |  | 
**address** | **str** |  | 

## Example

```python
from openapi_client.models.external_api_holding_base_previous_owner_request import ExternalAPIHoldingBasePreviousOwnerRequest

# TODO update the JSON string below
json = "{}"
# create an instance of ExternalAPIHoldingBasePreviousOwnerRequest from a JSON string
external_api_holding_base_previous_owner_request_instance = ExternalAPIHoldingBasePreviousOwnerRequest.from_json(json)
# print the JSON string representation of the object
print(ExternalAPIHoldingBasePreviousOwnerRequest.to_json())

# convert the object into a dict
external_api_holding_base_previous_owner_request_dict = external_api_holding_base_previous_owner_request_instance.to_dict()
# create an instance of ExternalAPIHoldingBasePreviousOwnerRequest from a dict
external_api_holding_base_previous_owner_request_from_dict = ExternalAPIHoldingBasePreviousOwnerRequest.from_dict(external_api_holding_base_previous_owner_request_dict)
```
[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


